@@ -29,7 +29,7 @@ Rose::DB::Object::Metadata::Column::Serial - Serial column metadata.
 
 Objects of this class store and manipulate metadata for serial columns in a database.  Column metadata objects store information about columns (data type, size, etc.) and are responsible for creating object methods that manipulate column values.
 
-This class inherits from C<Rose::DB::Object::Metadata::Column::Scalar>. Inherited methods that are not overridden will not be documented a second time here.  See the C<Rose::DB::Object::Metadata::Column::Scalar> documentation for more information.
+This class inherits from L<Rose::DB::Object::Metadata::Column::Scalar>. Inherited methods that are not overridden will not be documented a second time here.  See the L<Rose::DB::Object::Metadata::Column::Scalar> documentation for more information.
 
 =head1 OBJECT METHODS
 
@@ -37,7 +37,7 @@ This class inherits from C<Rose::DB::Object::Metadata::Column::Scalar>. Inherite
 
 =item B<method_maker_class>
 
-Returns C<Rose::DB::Object::MakeMethods::Generic>.
+Returns L<Rose::DB::Object::MakeMethods::Generic>.
 
 =item B<method_maker_type>
 
